import React, {Component} from "react";
import classNames from "classnames";
import Isvg from 'react-inlinesvg';
import ScrollArea from 'react-scrollbar';
import ReactDOM from 'react-dom';
require("./errorsPanel.scss");

export default class extends Component {
    toggleErrorsState() {
        this.props.toggleErrorsState();
    }

    removeError(id) {
        this.props.removeError(id);
    }

    componentDidUpdate(prevProps) {
        const {errorsPanelSize} = prevProps;
        const boundingClientRect = ReactDOM.findDOMNode(this).getBoundingClientRect();
        if (errorsPanelSize.height !==  boundingClientRect.height)
            this.props.broadcastErrorsPanelSize(boundingClientRect);
    }

    componentDidMount() {
        this.props.broadcastErrorsPanelSize(ReactDOM.findDOMNode(this).getBoundingClientRect());
    }

    render() {
        const {errors, errorsPanelOpen} = this.props;
        const isOpen = (errors && errors.length > 0) && errorsPanelOpen;
        const errorsContainer=  (
            <div className="errors-container clearfix">{errors.map(error =>
                <ErrorItem error={error} key={error.id} remove={this.removeError.bind(this)}></ErrorItem>)}
            </div>
        );

        return (
            <div className={classNames("errors-panel", {"is-visible": isOpen})}>
                <div className="errors-header">
                    <div>
                         <Isvg cacheGetRequests={true} src={require("./../../assets/svgs/errors-footer.svg")}></Isvg>
                        {errors.length} {errors.length === 1 ? 'Error' : 'Errors'}
                    </div>
                    <div onClick={this.toggleErrorsState.bind(this)}>
                         <Isvg cacheGetRequests={true} src={require("./../../assets/svgs/errors-mimimize.svg")}></Isvg>
                    </div>
                </div>
                {errors.length > 4 && <ScrollArea
                    style={{ width: "100%", height: 236 }}
                    className="area"
                    contentClassName="content"
                    verticalScrollbarStyle={{borderRadius: 0, backgroundColor: "#818483", width: "5px", position: "relative"}}
                    verticalContainerStyle={{borderRadius: 0, opacity: 1, width: "5px"}}
                    horizontal={false}
                    smoothScrolling= {true}
                    minScrollSize={35}
                    >
                    {errorsContainer}
                </ScrollArea>}
                {errors.length <= 4 && errorsContainer}
            </div>
        )
    }

}

const ErrorItem = ({error, remove}) => {
    return (
        <div className="error-item">
            <div>{error.message}</div>
            <div>
                <button onClick={() => remove(error.id)}>X</button>
            </div>

        </div>
    )
};
