import React from 'react';
import ReactPopover from "../reactPopover/ReactPopover";
import Isvg from 'react-inlinesvg';
import {Link} from "react-router-dom";
import {ApolloConsumer} from "react-apollo";

require('./header.scss');
require('../../buttons.scss');

const UserWidget = ({fullName, email}) => (
    <ApolloConsumer>
        {appClient => {
            return (
                <div className="user">
                    <ReactPopover popoverClass="user-menu"
                                  container={<button type="button" className="primary">{fullName} <Isvg
                                      cacheGetRequests={true}
                                      src={require("./../../assets/svgs/left-chevron-thick.svg")}></Isvg>
                                  </button>}>
                        <ul className="no-bullet">
                            <li><span title={email}>{email}</span></li>
                            <li>
                                <button type="button" className="popover" onClick={async () => {
                                    await appClient.clearStore();
                                    window.auth.logout()
                                }}><Isvg
                                    cacheGetRequests={true}
                                    src={require("./../../assets/svgs/exit-door-icon.svg")}></Isvg>Log
                                    Out
                                </button>
                            </li>
                        </ul>
                    </ReactPopover>
                </div>
            )
        }}
    </ApolloConsumer>
);

export default ({auth, nakedHeader, noNavigationToDashboard, children}) => {
    const user = auth.data || {};
    user.fullName = auth.fullName;
    const userWidget = !nakedHeader && auth.authenticated ? <UserWidget {...user}></UserWidget> : '';
    if (nakedHeader) {
        document.body.classList.add("no-sso");
        document.body.classList.add("naked");
        document.body.classList.remove("with-sso");
    }
    return (
        <header className="primary">
            {!nakedHeader && !noNavigationToDashboard && <Link to="/" className="logo">
                <Isvg cacheGetRequests={true} src={require("./../../assets/svgs/logo-white.svg")}/>
                Cloud Tiering
            </Link>}
            {!nakedHeader && noNavigationToDashboard && <div className="logo">
                <Isvg cacheGetRequests={true} src={require("./../../assets/svgs/logo-white.svg")}/>
                Cloud Tiering
            </div>}
            {children}
            {userWidget}
        </header>
    );
};

