import React, {Component} from 'react';
import {Query} from 'react-apollo'
import LoadingIcon from '../../../components/widgets/LoadingIcon'
import Subscribe from './Subscribe';
import {LICENSE_TYPE_FREE_TRIAL, LICENSE_TYPE_PAYGO, FREE_TRIAL_PERIOD} from "../../../utils/consts";
import Isvg from "react-inlinesvg"
import _ from "lodash";
import {buildCapacityObject} from "../../../utils/utils";
import {GET_CLUSTERS_AND_ACCOUNT_INFO_QUERY} from "../../../queries";

require("./licenseSettings.scss");

export const LicenseHeader = () => (<div className="license-header">
    <h3>Licensing</h3>
</div>);


const getHeaderText = (licenseType, subscribed, pending) => {
    switch (licenseType) {
        case LICENSE_TYPE_FREE_TRIAL:
            return <span>The free trial has started.</span>;
        case LICENSE_TYPE_PAYGO:
            if (!subscribed && !pending) {
                return (
                    <div className="header-error">
                        <Isvg cacheGetRequests={true}
                              src={require("../../../assets/svgs/exclamation-mark-triangle-icon.svg")}/>
                        <span>{`The ${FREE_TRIAL_PERIOD}-day free trial has ended.`}</span>
                    </div>
                )
            }
            return <span></span>;
        default:
            return <span></span>
    }
};

const HeaderItem = ({item: {count, title}}) => {
    return (
        <div className="licensing-header-item">
            <div className="header-item-count">{count}</div>
            <div className="header-item-title">{title}</div>
        </div>
    )
};

const Header = ({headerItems, headerText}) => {
    return (
        <div className="licensing-header">
            <div className="header-counters">{headerItems.map((item, index) => <HeaderItem key={index}
                                                                                           item={item}/>)}</div>
            <div className="header-text">{headerText}</div>
        </div>
    )
};

const ContactUs = () => {
    return (<div className="contact-us">
            <Isvg className="float-center" cacheGetRequests={true} src={require('../../../assets/svgs/envelope.svg')}/>
            <p>For more info <a href="mailto:ng-cloudsync-contact@netapp.com?subject=Cloud Sync - License Support">contact
                us</a></p>
        </div>
    )
};


class LicenseSettings extends Component {
    render() {
        return (
            <Query query={GET_CLUSTERS_AND_ACCOUNT_INFO_QUERY} fetchPolicy="network-only" pollInterval={30*1000}>
                {({loading, data}) => {
                    if (loading)
                        return (<LoadingIcon text={"Account Information"} icon={<Isvg
                            src={require('../../../assets/svgs/logo.svg')}/>}/>);
                    const {clusters, accountInfo: {daysLeftForTrial, subscriptionStatus}} = data;
                    const freeTrial = daysLeftForTrial > 0;
                    const licenseType = freeTrial ? LICENSE_TYPE_FREE_TRIAL : LICENSE_TYPE_PAYGO;
                    const subscribed = subscriptionStatus === "subscribed";
                    const pending = subscriptionStatus === "pending" || subscriptionStatus === "unsubscribe_pending";
                    const totalTiered = buildCapacityObject(_.reduce(clusters, (count, cluster) => count + _.get(cluster, ["tierInformation", "tieredCapacity"], 0), 0));
                    const headerItems = [
                        {count: clusters.length, title: "Clusters"},
                        {count: `${totalTiered.value} ${totalTiered.unit}`, title: "Total Tiered Data"}
                    ];

                    return (<div className="license-settings">
                            <div className="content center">
                                <Header headerItems={headerItems}
                                        headerText={getHeaderText(licenseType, subscribed, pending)}/>
                                <Subscribe freeTrial={freeTrial}
                                           status={subscriptionStatus}
                                />
                                <ContactUs/>
                            </div>
                        </div>
                    );
                }}
            </Query>
        )
    }
}

export default LicenseSettings;