import React from 'react';
import {openDialog} from "../../dialog/Dialog"
import {DOCUMENTATION_URL, FREE_TRIAL_PERIOD} from "./../../../utils/consts";
import SubscriptionFlowDialog from "./SubscriptionFlowDialog";
import Isvg from 'react-inlinesvg';

require("./subscribe.scss");

const SubscriptionContent = ({data: {subscribed, failedToSubscribe, freeTrial, pending, pendingUnsubscribe}}) => {
    const renderSubscribeTitle = () => {

        if (subscribed) {
            return (
                <div className="icon-with-title">
                    <Isvg cacheGetRequests={true} src={require("../../../assets/svgs/checkmark-circle-icon.svg")}/>
                    <span>Active Subscription - AWS Marketplace pay-as-you-go</span>
                </div>
            );
        }

        if (failedToSubscribe) {
            return (
                <div className="icon-with-title failed">
                    <Isvg cacheGetRequests={true} src={require("../../../assets/svgs/x-circle-icon.svg")}/>
                    <span>Failed to subscribe from the AWS Marketplace</span>
                </div>
            );
        }
        if (pending || pendingUnsubscribe) {
            return (
                <div className="icon-with-title pending">
                    <Isvg cacheGetRequests={true} src={require("../../../assets/svgs/pending-icon.svg")}/>
                    <span>Pending {pending ? "Subscription" : "Unsubscribe"}</span>
                </div>
            );
        }
        return <span>Subscribe from the AWS Marketplace</span>

    };

    const renderSubscribeText = () => {
        // build text dynamically
        let subscribeText;
        if (pending) {
            subscribeText = `Your subscribe request from the AWS Marketplace is pending`
        }
        else if (pendingUnsubscribe) {
            subscribeText = `Your unsubscribe request from the AWS Marketplace is pending`
        }
        else if (failedToSubscribe && !freeTrial) {
            subscribeText = `The free trail has ended, to continue using this service and tier your data, you should unsubscribe from the AWS Marketplace and start the subscription process again`
        }
        else if (failedToSubscribe && freeTrial) {
            subscribeText = `Unsubscribe from the AWS Marketplace and start the subscription process again`
        }
        else if (subscribed && freeTrial) {
            subscribeText = `After the ${FREE_TRIAL_PERIOD}-day free trial is over, you will be charged hourly according to the amount of data you tier`;
        }

        else if (subscribed && !freeTrial) {
            subscribeText = `You will be charged hourly according to the amount of data you tier`;
        }

        else if (!subscribed && freeTrial) {
            subscribeText = `Subscribe from the AWS Marketplace and after the ${FREE_TRIAL_PERIOD}-day free trial is over,
                        you will be charged hourly according to the amount of data you tier`
        }

        else if (!subscribed && !freeTrial) {
            subscribeText = `The free trial has ended, to continue using this service and tier your data, you must subscribe from the AWS Marketplace. You will be charged hourly according to the amount of data you tier.  View the pricing model`
        }

        subscribeText += '.';

        // only show price model link when subscribed (otherwise pricing model is shown on subscribe page itself)
        if (subscribed ||(!subscribed && !freeTrial && !failedToSubscribe && !pending && !pendingUnsubscribe)) {
            return (
                <span>
                    {subscribeText}
                    <a href="https://aws.amazon.com/marketplace/pp/B07QV3N5LM" target="_blank" rel="noopener noreferrer" > View the pricing model</a>
                </span>
            );
        }


        return <span>{subscribeText}</span>;
    };



    return (
      <div className="subscription-content">
          <div className="subscription-content-title">{renderSubscribeTitle()}</div>
          <div className="subscription-content-info">{renderSubscribeText()}</div>
      </div>
  )
};

const showSubscribeConfirmation = (clickElement) => {
    openDialog(<SubscriptionFlowDialog className="confirm subscription-flow-dialog"
                                       marketplaceLink="https://aws.amazon.com/marketplace/pp/B07QV3N5LM"
                                       marketplaceInstructions="At the AWS Marketplace, you should click Continue, then Subscribe, and then Set Up Your Account."
                                       backToCloudTieringInstructions="You are then redirected back to Cloud Tiering where you must log in again to complete the subscription."
                                       videoLink={`${DOCUMENTATION_URL}#subscribe`}/>, clickElement.target);
};

const showUnsubscribeConfirmation = (clickElement) => {
    openDialog(<SubscriptionFlowDialog className="confirm subscription-flow-dialog"
                                       marketplaceLink="https://aws.amazon.com/marketplace/library"
                                       marketplaceInstructions="At the AWS Marketplace, look for Cloud Tiering Service and click CANCEL SUBSCRIPTION."
                                       backToCloudTieringInstructions="You should then return to Cloud Tiering to start the subscription process again."/>, clickElement.target);
};

export default ({freeTrial, status}) => {
    const subscribed = status === "subscribed";
    const failedToSubscribe = status === "failed";
    const pending = status === "pending";
    const pendingUnsubscribe = status === "unsubscribe_pending";

    return (
        <div className="subscription">
            <div><Isvg cacheGetRequests={true} src={require('../../../assets/svgs/marketplace.svg')}/></div>
            <SubscriptionContent data={{subscribed, failedToSubscribe, freeTrial, pending, pendingUnsubscribe}}/>
            <div className={`subscription-action ${status}`}>
                {failedToSubscribe && <button className="button" onClick={(clickElement) => showUnsubscribeConfirmation(clickElement)}>Unsubscribe</button>}
                {!subscribed && !failedToSubscribe && <button className="button" onClick={(clickElement) => showSubscribeConfirmation(clickElement)}>Subscribe</button>}
            </div>
        </div>
    )
};
