import React, {Component, Fragment} from 'react';
import {connect} from 'react-redux';
import {Route, Switch} from 'react-router-dom';
import {Field, reduxForm} from 'redux-form';
import {InputField, SelectField} from "../forms/forms";
import stepinize from "./../wizard/stepinize";
import mapStateToProps from './wizardMapStateToProps'
import Validator from 'validatorjs';
import ButtonWithError from './../widgets/ButtonWithError';
import Isvg from "react-inlinesvg";
import {Query} from "react-apollo";
import {GET_REGIONS_QUERY} from "../../queries";
import _ from "lodash"
import localStorage from 'local-storage';
import LoadingIcon from '../widgets/LoadingIcon'
import classNames from "classnames";
import {calculateNextStep} from "./WizardStarter";
import {STORAGE_CLASSES, STORAGE_CLASS_INFO, DEFAULT_STORAGE_CLASS} from "../../utils/consts"
import ReactPopover from "../reactPopover/ReactPopover";
import {getNextStepComponent} from "./WizardStarter";

require('./bucketStep.scss');

const rules = {
    accessKey: 'required',
    secretKey: 'required',
    region: 'required'
};


const validate = (values, props) => {
    const {match: {params: {provider}}} = props;

    let errors = {};
    const validator = new Validator(values, rules);
    if (provider === "AWS") {
        validator.setAttributeNames({accessKey: "AWS Access Key", secretKey: "AWS Secret Key", region: 'S3 Bucket Region'});
    }
    else {
        validator.setAttributeNames({region: 'Azure Blob Region'});
    }
    validator.passes();
    errors = validator.errors.all();
    return errors;
};

class BucketStep extends Component {
    constructor(props, context) {
        super(props, context);
        const {wizard, change, match: {params: {provider}}} = this.props;
        const selectedAwsKeys = localStorage.get("selectedAwsKeys");
        const stateObject = {
            region: _.get(wizard.selectedWizardParams, ["region"], undefined),
            storageClass: _.get(wizard.selectedWizardParams, ["storageClass"], STORAGE_CLASSES[provider][DEFAULT_STORAGE_CLASS].storageClass),
            selectedAwsKeys: selectedAwsKeys || {accessKey: "", secretKey: ""}
        };
        this.state = stateObject;
        if (stateObject.region !== undefined) {
            change("region", stateObject.region);
        }
        if (stateObject.storageClass !== undefined) {
            change("storageClass", stateObject.region);
        }
        change("accessKey", stateObject.selectedAwsKeys.accessKey);
        change("secretKey", stateObject.selectedAwsKeys.secretKey);
    }

    UNSAFE_componentWillReceiveProps() {
        if (this.state && !this.state.region && this.props.wizard && this.props.wizard.selectedWizardParams && this.props.wizard.selectedWizardParams.region) {
            const {change, wizard: {selectedWizardParams: {region}}} = this.props;
            this.setState({region});
            change("region", region);
        }
    }

    submit(values) {
        const region = this.state.region || values.region;
        const storageClass = this.state.storageClass || values.storageClass;
        return Promise.resolve(true)
            .then(() => {
                localStorage.set("selectedAwsKeys", {accessKey: values.accessKey, secretKey: values.secretKey});
                const nextStep = calculateNextStep(this.props.wizard);
                this.props.wizard.nextStep(`/${region}/${storageClass}/${nextStep}`, this.props.history);
            });

    }

    changeRegionSelection(selectedOptions) {
        this.setState(Object.assign({}, this.state, {region: selectedOptions}));
    }

    changeStorageClassSelection(selectedOptions) {
        this.setState(Object.assign({}, this.state, {storageClass: selectedOptions}));
    }

    getContentUX(provider, data) {
        const region = this.state.region;
        const storageClass = this.state.storageClass;

        const {regions} = data;
        const regionOptions = _.map(regions, region => {
            return {label: region.regionName, value: region.region};
        });
        const storageClassOptions = _.map(STORAGE_CLASSES[provider], storageClass => {
            return {label: storageClass.storageClassName, value: storageClass.storageClass};
        });
        const selectedRegion = _.find(regionOptions, {value: region}) || "";
        const selectedStorageClass = _.find(storageClassOptions, {value: storageClass}) || "";

        switch (provider) {
            case "AZURE" : {
                return (
                    <div className="pane center">
                        <div>
                            <Field component={SelectField} label="Region"
                                   onChange={this.changeRegionSelection.bind(this)}
                                   valueField="value" name="region" options={regionOptions}
                                   selectedValue={selectedRegion}
                                   className="region" noSearch={true}></Field>
                        </div>
                        <div className="storage-class-container">
                            <label>
                                Blob Storage Tiering
                                <ReactPopover popoverClass="storage-class-popover-content" contentStyle={{width: "483px"}}
                                              trigger="mouseover-exit-click"
                                              container={<button className="info" type="button">
                                                  <Isvg cacheGetRequests={true} src={require("./../../assets/svgs/info-circle-icon.svg")}></Isvg></button>}>
                                    {STORAGE_CLASS_INFO[provider]}
                                </ReactPopover>
                            </label>
                            <Field component={SelectField}
                                   onChange={this.changeStorageClassSelection.bind(this)}
                                   valueField="value" name="storageClass"
                                   options={storageClassOptions}
                                   selectedValue={selectedStorageClass}
                                   className="storage-class" noSearch={true}></Field>
                        </div>
                    </div>

                )
            }
            case "AWS": {
                return (
                    <Fragment>
                        <div className="pane left">
                            <div className="">
                                <Field name="accessKey" component={InputField} label="AWS Access Key"
                                       type="text"></Field>
                            </div>
                            <div className="">
                                <Field name="secretKey" component={InputField} label="AWS Secret Key"
                                       type="password"></Field>
                            </div>
                        </div>
                        <div className="pane right">
                            <div>
                                <div>
                                    <Field component={SelectField} label="S3 Bucket Region"
                                           onChange={this.changeRegionSelection.bind(this)}
                                           valueField="value" name="region" options={regionOptions}
                                           selectedValue={selectedRegion}
                                           className="region" noSearch={true}></Field>
                                </div>
                                <div className="storage-class-container">
                                    <label>
                                        Storage Class
                                        <ReactPopover popoverClass="storage-class-popover-content" contentStyle={{width: "483px"}}
                                                      trigger="mouseover-exit-click"
                                                      container={<button className="info" type="button">
                                                          <Isvg cacheGetRequests={true} src={require("./../../assets/svgs/info-circle-icon.svg")}></Isvg></button>}>
                                            {STORAGE_CLASS_INFO[provider]}
                                        </ReactPopover>
                                    </label>
                                    <Field component={SelectField}
                                           onChange={this.changeStorageClassSelection.bind(this)}
                                           valueField="value" name="storageClass"
                                           options={storageClassOptions}
                                           selectedValue={selectedStorageClass}
                                           className="storage-class" noSearch={true}></Field>
                                </div>
                            </div>
                        </div>
                    </Fragment>
                )
            }
            default : {
                return <div>Unknown Provider {provider}</div>
            }
        }
    }

    handleError(error) {
        let errorMessage;
        if (error.networkError && error.networkError.result && error.networkError.result.errors)
            errorMessage = error.networkError.result.errors[0].message;
        else if (error.graphQLErrors)
            errorMessage = error.graphQLErrors[0].message;
        else console.log(`%c BucketStep got GraphQL error ${JSON.stringify(error)}`, "font-weight:bold; color: red");
        if (errorMessage && this.state.error !== errorMessage) {
            this.setState({error: errorMessage});
        }
    }

    render() {
        if (!this.state || !this.props.wizard || !this.props.routingInfo || !this.props.routingInfo.urlParams || !this.props.routingInfo.urlParams.decodedParams.clusterId) {
            return <div>No Wizard or routing params yet...</div>
        }

        const {routingInfo: {urlParams: {decodedParams: {provider, clusterId}}}, handleSubmit, error: propsError, up} = this.props;
        const stateError = this.state.error;
        return (
            <div className={classNames("bucket-step wizard-step", {up, down: !up})}>
                <form onSubmit={handleSubmit(this.submit.bind(this))}>
                    <Query query={GET_REGIONS_QUERY} variables={{type: provider, clusterId}}
                           onError={this.handleError.bind(this)}
                           skip={!provider}>
                        {({loading, error, data}) => {
                            if ((loading || !data) && !error) {//due to skip there might not be data yet
                                return (<LoadingIcon text={"Regions"} className="loading-regions" icon={<Isvg
                                    src={require('../../assets/svgs/bucket-icon.svg')}/>}/>);
                            }
                            return (
                                <div>
                                    <div className="step-title">
                                        <Isvg cacheGetRequests={true}
                                              src={require("./../../assets/svgs/bucket-icon.svg")}/>
                                        <h3>{provider === "AWS" ? "AWS S3 Bucket" : "Azure Blob"}</h3>
                                        <div className="step-title-info">
                                            {provider === "AWS" ? "Cloud Tiering will create S3 bucket for you, the tiered data will be transferred to the S3 Bucket." :
                                                "Cloud Tiering will create blob storage for you, the tiered data will be transferred to the blob."}
                                        </div>
                                        {provider === "AWS" && <div className="step-title-info">
                                            Providing your keys is secure and private, NetApp does not save them.<br/>
                                            Make sure that your AWS account has the permission defined in the
                                            <a
                                                href="https://docs.netapp.com/us-en/cloud-tiering/task_preparing.html#preparing-your-object-storage-provider"
                                                target="_blank" rel="noopener noreferrer"> Policy Requirements
                                            </a>
                                        </div>}

                                    </div>
                                    {!error && data && <div className="step-content">
                                        {this.getContentUX(provider, data)}
                                    </div>}
                                    <div className="wizard-button">
                                        <ButtonWithError className="button secondary" type="submit"
                                                         error={propsError || stateError}>
                                            Continue
                                        </ButtonWithError>
                                    </div>
                                </div>
                            )
                        }}
                    </Query>
                </form>
            </div>
        )
    }
}

const nextRoutes = ({match, wizard}) => {
    const nextStep = calculateNextStep(wizard, "Bucket");
    const NextStepComp = getNextStepComponent(nextStep);
    return (
        <Switch>
            <Route path={`${match.url}/:region/:storageClass/${nextStep}`} render={(props) => <NextStepComp {...props}/>}/>
        </Switch>
    )
};

let BucketStepForm = reduxForm({
    form: 'bucketForm',
    validate
})(BucketStep);

export default connect(mapStateToProps)(stepinize(BucketStepForm, {
    name: () => `Bucket`,
    nextRoutes,
}));
