import React, {Component} from 'react'
import {TIERING_POLICY} from "../../utils/consts"
import Isvg from 'react-inlinesvg';
import _ from 'lodash'

require('./tieringPolicyDialog.scss');

export default class TieringPolicyDialog extends Component {
    constructor(props, context) {
        super(props, context);
        const {ontapVersion} = props;
        const withOpenState = _.keys(TIERING_POLICY).map((key) => {
            const policy = TIERING_POLICY[key];
            return {
                open: false,
                disabled: policy.notSupportedBelow && ontapVersion < policy.notSupportedBelow,
                ...policy
            }
        });
        const {tieringPolicy} = this.props;

        this.state = {selected: tieringPolicy, withOpenState};
    }

    selectTieringPolicy(event) {
        const tieringPolicy = TIERING_POLICY[event.target.value];
        this.setState({selected: tieringPolicy});
    }

    updateOpenState(type, openState) {
        const withOpenState = this.state.withOpenState.map((policy) => {
            if (policy.type === type) {
                policy.open = openState;
            }
            return policy;
        });
        this.setState({withOpenState});
        if (openState) {
            const selectedPolicy = _.find(this.state.withOpenState, {type});
            if (!selectedPolicy.disabled)
                this.setState({selected: selectedPolicy});
        }
    };

    render() {
        const {closeDialog, apply} = this.props;
        return (
            <div className="tiering-policy-dialog-content">
                <h4>Volume Tiering Policy</h4>
                <div className="tiering-policy-content-title">Choose a tiering policy for the selected volumes.</div>
                <form>
                    {this.state.withOpenState.map((policy) => {
                        const titleComponent = <><b>{policy.name} - </b> <span
                            className="policy-title">{policy.disabled ? policy.notSupportedTitle : policy.title}</span></>;
                        return (
                            <div key={policy.type} className={`policy-radio ${policy.disabled ? "disabled" : ""}`}>
                                <input type="radio" name={policy.type} value={policy.type}
                                       checked={this.state.selected.type === policy.type}
                                       onChange={this.selectTieringPolicy.bind(this)} disabled={policy.disabled}
                                />
                                {!policy.open &&
                                <button onClick={this.updateOpenState.bind(this, policy.type, true)}>{titleComponent}<Isvg
                                    src={require('../../assets/svgs/triangle-down.svg')}/></button>}
                                {policy.open &&
                                <button onClick={this.updateOpenState.bind(this, policy.type, false)}>{titleComponent}<Isvg
                                    src={require('../../assets/svgs/triangle-up.svg')}/></button>}
                                {policy.open && <div className="policy-details">{policy.details}</div>}
                            </div>
                        )
                    })}
                </form>
                <div className="bottom-button-row">
                    <button className="button secondary" type="button"
                            onClick={() => {
                                apply(this.state.selected);
                                closeDialog();
                            }}>Apply
                    </button>
                    <button className="button grey" type="button" onClick={closeDialog}>Cancel</button>
                </div>
            </div>
        )
    }
}

