import Immutable from "seamless-immutable";
import moment from "moment";
import {BROADCAST_ERRORS_PANEL_SIZE, CLEAR_ERRORS, GENERAL_ERROR, REMOVE_ERROR, TOGGLE_ERRORS_STATE} from "../actions";
import _ from 'lodash';


export const defaultState = () => Immutable({
    generalErrors: {errorsMap: {}, errorsPanelSize: {height: 0}, errorsPanelOpen: false}
});

export default (state = defaultState(), {payload, type, code}) => {
    switch(type) {
        case GENERAL_ERROR: {
            const errorTime = moment();
            const error = {
                id: code,
                message: payload,
                time: errorTime
            };
            return updateErrorsPanelStatus(state.updateIn(["generalErrors","errorsMap"], errorsMap => errorsMap.set(code, error)));
        }
        case TOGGLE_ERRORS_STATE: {
            return state.updateIn(["generalErrors", "errorsPanelOpen"], errorsPanelOpen => !errorsPanelOpen);
        }
        case REMOVE_ERROR: {
            return updateErrorsPanelStatus(state.updateIn(["generalErrors", "errorsMap"], errors => errors.without(payload)));
        }
        case BROADCAST_ERRORS_PANEL_SIZE: {
            return state.updateIn(["generalErrors"], generalErrors => generalErrors.set("errorsPanelSize", {height: payload.height}));
        }
        case CLEAR_ERRORS: {
            return updateErrorsPanelStatus(state.setIn(["generalErrors", "errorsMap"], {}));
        }
        default:
            return state;
     }
};

const updateErrorsPanelStatus = (state) => {
    if (_.isEmpty(state.generalErrors.errorsMap)) return state.setIn(["generalErrors","errorsPanelOpen"], false).setIn(["generalErrors","errorsPanelSize"], {height: 0});
    return state.setIn(["generalErrors","errorsPanelOpen"], true);
};

