import React from 'react'
import Isvg from 'react-inlinesvg'

export const SHOW_TRIAL_INFO = process.env.REACT_APP_TRIAL === "true";

export const CLUSTER_STATUS = {
    ON: "ON",
    FAILED: "FAILED",
    UNKNOWN: "UNKNOWN"
};

export const TIER_BUTTON_TEXT = "Set up Tiering";

export const PROVIDER_TYPE_AWS = {
    type: "aws",
    name: 'AWS',
    icon: <Isvg cacheGetRequests={true} src={require(`./../assets/svgs/aws-color.svg`)} className="aws"/>,
};

export const PROVIDER_TYPE_AZURE = {
    type: "azure",
    name: 'AZURE',
    icon: <Isvg cacheGetRequests={true} src={require(`./../assets/svgs/azure-color.svg`)} className="azure"/>
};

export const PROVIDER_TYPE_GCP = {
    type: "gcp",
    name: 'GCP',
    icon: <Isvg cacheGetRequests={true} src={require(`./../assets/svgs/gcp-color.svg`)} className="gcp"/>,
    soon: true
};

export const PROVIDER_TYPE_SG = {
    type: "sg",
    name: 'SG',
    icon: <Isvg cacheGetRequests={true} src={require(`./../assets/svgs/sg-color.svg`)} className="sg"/>,
    soon: true
};

export const PROVIDERS = {
    "AWS": PROVIDER_TYPE_AWS,
    "AZURE": PROVIDER_TYPE_AZURE,
    "GCP": PROVIDER_TYPE_GCP,
    "SG": PROVIDER_TYPE_SG
};


export const DASHBOARD_TITLES = {
    dataNotAvailable: "No Available Data",
    notTiered: "Cold data has not been tiered yet",
    allTiered: "Data tiering is enabled on all volumes",
    estimated: "The cold data is an estimate based on industry standards. We estimate that 70% of the data in the performance tier is cold data that you can move to lower-cost object storage. For ONTAP 9.4 and later, Cloud Tiering replaces the estimate with a precise value, as soon as it discovers more information about the system. The discovery period is approximately 31 days."
};

export const VOLUMES_STEP_INFO = {
    DISPLAYED_VOLUMES: <span>The total number of volumes that Cloud Tiering displays might be less than the number of volumes on your ONTAP system. That's because some volumes can't be tiered. For example, you can't tier data from SnapLock volumes or from MetroCluster configurations. Refer to ONTAP Documentation for features not supported by FabricPool.</span>,
    USED_SIZE: <span>The amount of space occupied by user data and file system metadata.</span>,
    COLD_DATA: <span>The amount of inactive data on the volume that you can tier to object storage.</span>,
    COLD_DATA_ESTIMATED: <span>The amount of inactive data on the volume that you can tier to object storage. {DASHBOARD_TITLES.estimated}</span>
};

export const AGENT_STATUS = {
    pending: {status: "pending", order: 2},
    active: {status: "active", order: 1},
    inactive: {status: "inactive", order: 3},
    unknown: {status: "unknown", order: 4}
};

export const AGENT_NAME = "Service Connector";


export const STORAGE_CLASSES = {
    "AWS" : [
            {storageClassName: "Standard-Infrequent Access", storageClass: "standard_ia"},
            {storageClassName: "Standard", storageClass: "standard"}
            ],
    "AZURE" : [
        {storageClassName: "Hot", storageClass: "hot"},
    ]
};

export const DEFAULT_STORAGE_CLASS = 0;

export const STORAGE_CLASS_INFO = {
    "AWS": <span>Refer to <a href="https://aws.amazon.com/s3/storage-classes/" target="_blank"
                             rel="noopener noreferrer"> AWS documentation </a> for more details about S3 storage classes.</span>,
    "AZURE": <span>Refer to <a href="https://docs.microsoft.com/en-us/azure/storage/blobs/storage-blob-storage-tiers" target="_blank"
                               rel="noopener noreferrer"> AZURE documentation </a> for more details about Blob storage tiering.</span>
};

export const TIERING_POLICY = {
    "auto" : {
        type: "auto",
        name: "Auto",
        title: "Tiers cold user data and snapshot copies",
        details: "The Auto policy tiers all cold blocks in the volume to object storage. Data is tiered only after an aggregate has reached 50% capacity and when the data has reached the cooling period, which is approximately 31 days.",
        notSupportedBelow: 9.4,
        notSupportedTitle: "Supported with ONTAP 9.4 and later"
    },
    "snapshot_only" : {
        type: "snapshot_only",
        name: "Snapshot Only",
        title: "Tiers cold Snapshot copies.",
        details: "The Snapshot Only policy tiers cold user data blocks of Snapshot copies that are not associated with the active file system to object storage. Data is tiered only after an aggregate has reached 50% capacity and when the data has reached the cooling period, which is approximately 2 days."
    }
};

export const DOCUMENTATION_URL = "https://docs.netapp.com/us-en/cloud-tiering/index.html";
export const FREE_TRIAL_PERIOD = 60;
export const LICENSE_TYPE_FREE_TRIAL = "Free Trial";
export const LICENSE_TYPE_PAYGO = "PayGo";
export const DEFAULT_IP_SPACE = "Default";