import React, {Component, Fragment} from 'react'
import {Query} from "react-apollo";
import LoadingIcon from "./components/widgets/LoadingIcon";
import Isvg from "react-inlinesvg";
import {get} from "lodash"

export const withQuery = (WrappedComponent, query, options) => {
    return class extends Component {
        render() {
            return (<Query query={query} options={get(options, "queryOptions", {})}>
                {({loading, error, data}) => {
                    if (loading)
                        return (<LoadingIcon text={options.loadingText} icon={<Isvg
                            src={require(`./assets/svgs/${options.loadingIcon}`)}/>}/>);
                    const errorMessage = error ? error.message : null;
                    return (
                        <Fragment>
                            {data && <WrappedComponent queryData={data} error={errorMessage} {...this.props}/>}
                            {errorMessage &&
                            <div className="error">
                                <Isvg className="error-icon" cacheGetRequests={true} src={require("./assets/svgs/error.svg")}/>
                                <span
                                    className="error-text">{`Unable to load got error: ${JSON.stringify(error)}`}</span>
                            </div>}
                        </Fragment>
                    )
                }}
            </Query>)
        }
    }
};
